@@ -20,7 +20,8 @@ class TextSet : public Shape {
 public:
   TextSet(Material& in_material, int in_ntexts, char** in_texts, double *in_center, 
           double in_adjx, double in_adjy,
-          int in_ignoreExtent, FontArray& in_fonts);
+          int in_ignoreExtent, FontArray& in_fonts,
+          int in_npos, const int* in_pos);
   ~TextSet();
   /* Can't use display lists */
   void render(RenderContext* renderContext);
@@ -45,7 +46,9 @@ private:
 
   double adjx;
   double adjy;
-
+  
+  int npos;
+  int* pos;
 };
 
 } // namespace rgl
