@@ -12,21 +12,26 @@ int SaveErrnum = GL_NO_ERROR;
 
 using namespace rgl;
 
+#ifndef RGL_NO_OPENGL
 static const char * SaveFile;
 static int SaveLine;
+#endif
 
 void saveGLerror(const char * file, int line)
 {
+#ifndef RGL_NO_OPENGL
   GLenum errnum;
   if (SaveErrnum == GL_NO_ERROR && (errnum = glGetError()) != GL_NO_ERROR) {
     SaveErrnum = errnum;
     SaveFile = file;
     SaveLine = line;
   }
+#endif
 }
 
 void checkGLerror(const char * file, int line)
 {
+#ifndef RGL_NO_OPENGL
   saveGLerror(file, line);
   if (SaveErrnum != GL_NO_ERROR) {
     int err = SaveErrnum;
@@ -34,5 +39,6 @@ void checkGLerror(const char * file, int line)
     while (glGetError() != GL_NO_ERROR) {} /* clear other errors, if any */
     error("OpenGL error at %s:%d: %s", SaveFile, SaveLine, gluErrorString(err));
   }
+#endif
 }
 
