@@ -66,7 +66,7 @@ public:
   inline  void unbind() { window = 0; }
   virtual void setTitle(const char* title) = 0;
   virtual void setWindowRect(int left, int top, int right, int bottom) = 0;
-  virtual void getWindowRect(int *left, int *top, int *right, int *bottom) = 0;
+  virtual void getWindowRect(int *in_left, int *in_top, int *in_right, int *in_bottom) = 0;
   virtual void show(void) = 0;
   virtual void hide(void) = 0;
   virtual void update(void) = 0;
