@@ -182,8 +182,6 @@ SEXP rgl_init(SEXP initValue, SEXP useNULL, SEXP in_namespace,
    {"rgl_getEmbeddings",        (DL_FUNC) &rgl_getEmbeddings, 2, aII},
    {"rgl_addtosubscene", 	(DL_FUNC) &rgl_addtosubscene, 3, aIII},
    {"rgl_delfromsubscene",	(DL_FUNC) &rgl_delfromsubscene, 3, aIII},
-   {"rgl_user2window",		(DL_FUNC) &rgl_user2window, 7, aLIDDDDI},
-   {"rgl_window2user", 		(DL_FUNC) &rgl_window2user, 7, aLIDDDDI},
    {"rgl_selectstate", 		(DL_FUNC) &rgl_selectstate, 5, aIILID},
    {"rgl_setselectstate",	(DL_FUNC) &rgl_setselectstate, 4, aIILI},
    {"rgl_quit",			(DL_FUNC) &rgl_quit, 1, aL},
@@ -236,8 +234,6 @@ SEXP rgl_init(SEXP initValue, SEXP useNULL, SEXP in_namespace,
    FUNDEF(rgl_getEmbeddings, 2),
    FUNDEF(rgl_addtosubscene, 3),
    FUNDEF(rgl_delfromsubscene, 3),
-   FUNDEF(rgl_user2window, 7),
-   FUNDEF(rgl_window2user, 7),
    FUNDEF(rgl_selectstate, 5),
    FUNDEF(rgl_setselectstate, 4),
    FUNDEF(rgl_quit, 1),
